.. _home:

===================
pyDVL Documentation
===================

Welcome to the pyDVL library for data valuation!

pyDVL collects algorithms for data valuation and influence function computation.
It runs most of them in parallel either locally or in a cluster and supports
distributed caching of results.

If you're a first time user of pyDVL, we recommend you to go through the
:ref:`Getting Started <getting started>` and
:ref:`Installation <pyDVL Installation>` guides.

.. grid:: 2
    :gutter: 4
    :padding: 4

    .. grid-item-card::
        :class-item: sd-text-center

        :material-regular:`home_repair_service;12em`

        .. button-ref:: 20-install
            :expand:
            :color: primary
            :outline:
            :click-parent:

            To the installation guide

    .. grid-item-card::
        :class-item: sd-text-center

        :material-regular:`code;12em`

        .. button-link:: https://github.com/appliedAI-Initiative/pyDVL
            :expand:
            :color: primary
            :outline:
            :click-parent:

            To the sources

    .. grid-item-card::
        :class-item: sd-text-center

        :material-regular:`description;12em`

        .. button-ref:: pydvl
            :expand:
            :color: primary
            :outline:
            :click-parent:

            Browse the API

    .. grid-item-card::
        :class-item: sd-text-center

        :material-regular:`computer;12em`

        .. button-link:: examples
            :expand:
            :color: primary
            :outline:
            :click-parent:

            To the examples

Contents
========

.. toctree::
   :glob:

   *
   examples/index

.. toctree::
   :caption: Reference
   :hidden:

   pydvl/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
